"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateRequest = exports.validateInteraction = void 0;
const noble_ed25519_1 = require("noble-ed25519");
//TODO: support more servers
function validateInteraction(publicKey, server = 'express') {
    switch (server) {
        case 'express':
        default: {
            return async function (req, res, next) {
                if (req.method !== 'POST') {
                    return res.sendStatus(405);
                }
                const isSigned = await validateRequest(publicKey, req.body, req.headers);
                if (!isSigned) {
                    return res.sendStatus(401);
                }
                if (req.body.type === 1) {
                    return res.json({ type: 1 });
                }
                next();
                return;
            };
        }
    }
}
exports.validateInteraction = validateInteraction;
async function validateRequest(publicKey, body, headers) {
    const signature = headers['x-signature-ed25519'];
    const timestamp = headers['x-signature-timestamp'];
    if (!signature || !timestamp) {
        return false;
    }
    const hash = Buffer.concat([
        Buffer.from(timestamp, 'utf-8'),
        Buffer.from(JSON.stringify(body)),
    ]);
    const isSigned = await noble_ed25519_1.verify(signature, hash, publicKey);
    if (!isSigned) {
        return false;
    }
    return true;
}
exports.validateRequest = validateRequest;
//# sourceMappingURL=slashCmdAuth.js.map